#
# spec file for package perl-Carp-Clan
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-Carp-Clan
Version:        6.08
Release:        1.22
%define cpan_name Carp-Clan
Summary:        Report errors from perspective of caller of a "clan" of modules
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
Url:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/E/ET/ETHER/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
This module is based on "'Carp.pm'" from Perl 5.005_03. It has been
modified to skip all package names matching the pattern given in the "use"
statement inside the "'qw()'" term (or argument list).

Suppose you have a family of modules or classes named "Pack::A", "Pack::B"
and so on, and each of them uses "'Carp::Clan qw(^Pack::);'" (or at least
the one in which the error or warning gets raised).

Thus when for example your script "tool.pl" calls module "Pack::A", and
module "Pack::A" calls module "Pack::B", an exception raised in module
"Pack::B" will appear to have originated in "tool.pl" where "Pack::A" was
called, and not in "Pack::A" where "Pack::B" was called, as the unmodified
"'Carp.pm'" would try to make you believe ':-)'.

This works similarly if "Pack::B" calls "Pack::C" where the exception is
raised, et cetera.

In other words, this blames all errors in the "'Pack::*'" modules on the
user of these modules, i.e., on you. ';-)'

The skipping of a clan (or family) of packages according to a pattern
describing its members is necessary in cases where these modules are not
classes derived from each other (and thus when examining '@ISA' - as in the
original "'Carp.pm'" module - doesn't help).

The purpose and advantage of this is that a "clan" of modules can work
together (and call each other) and throw exceptions at various depths down
the calling hierarchy and still appear as a monolithic block (as though
they were a single module) from the perspective of the caller.

In case you just want to ward off all error messages from the module in
which you "'use Carp::Clan'", i.e., if you want to make all error messages
or warnings to appear to originate from where your module was called (this
is what you usually used to "'use Carp;'" for ';-)'), instead of in your
module itself (which is what you can do with a "die" or "warn" anyway), you
do not need to provide a pattern, the module will automatically provide the
correct one for you.

I.e., just "'use Carp::Clan;'" without any arguments and call "carp" or
"croak" as appropriate, and they will automatically defend your module
against all blames!

In other words, a pattern is only necessary if you want to make several
modules (more than one) work together and appear as though they were only
one.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes CONTRIBUTING README
%license LICENSE

%changelog
* Mon Sep 16 2019 <timueller+perl@suse.de>
- updated to 6.08
  see /usr/share/doc/packages/perl-Carp-Clan/Changes
  6.08      2019-09-14 17:09:41Z
  - fix warning in bad test (thanks, Todd Rinaldo - RT#130494)
  - speed up code that was accomodating ancient perl versions that are no
    longer supported
* Thu Dec  6 2018 Stephan Kulow <coolo@suse.com>
- updated to 6.07
  see /usr/share/doc/packages/perl-Carp-Clan/Changes
* Sun May 29 2016 coolo@suse.com
- updated to 6.06
  see /usr/share/doc/packages/perl-Carp-Clan/Changes
  Version 6.06  29.05.2016
  + Avoid failure due to version self-check in 20pre560.t
    This test seems like a footgun for release management reasons, but apprently
    I wasn't quite as careful as I tried to be in keeping the last release minimal.
  Version 6.05  29.05.2016
  + Patch tests failing due to 5.25.1+'s deprecated unquoted { } in regex.
    (RT #114537)
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Wed Nov 24 2010 chris@computersalat.de
- recreated by cpanspec 1.78
  o fix deps
- noarch pkg
* Fri Jan 15 2010 anicka@suse.cz
- update to 6.04
  * Solved RT ticket #50796 (inform type of license)
  * Made the test suite compatible with Perl versions < v5.6.0
  * Re-release to resolve confusion in CPAN caused by intermediate
  release of Carp::Clan 5.4 (backport of bugfix #50560 below for
  Perls < v5.6.0)
  * Forgot to fix the bug of duplicated prefixes in _longmsg as well
  * Fixed bug of duplicated prefixes (RT ticket #50560)
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Feb 25 2008 anicka@suse.cz
- update to 6.00
  * Removed the circular dependency on Object::Deadly. It was only
  used for testing and would only succeed if you already had O::D
  installed.
* Mon Jun 18 2007 anicka@suse.cz
- update to 5.9
  * Test::Exceptions is mandatory for testing.
  * bugfix
* Wed Dec 13 2006 anicka@suse.cz
- update to 5.8
  * Stop testing that ->VERSION is a specific thing.
* Thu Oct  5 2006 anicka@suse.cz
- update to 5.7
  * Stop PAUSE from attempting to index DB package.
  * test fixes
  * bugfixes
  * Use named lexicals in diag().
  * Use exists &foo/defined &foo instead of symbol table hackery.
  * Changed f() so it accepts 1st parameter of
    carp/cluck/confess/croak instead of 1/2/3/4.
  * Renamed files.
* Mon Sep 25 2006 anicka@suse.cz
- update to 5.4
  * Made Carp::Clan safe for overloaded objects.
  * Added diag() to 01_..._carp.t
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Aug  1 2005 mjancar@suse.cz
- initial version 5.3
